@@ -111,30 +111,6 @@ void action_define (const char *defname, int value)
 	buf_append (&defs_buf, &cpy, 1);
 }
 
-
-#ifdef notdef
-/** Append "m4_define([[defname]],[[value]])m4_dnl\n" to the running buffer.
- *  @param defname The macro name.
- *  @param value The macro value, can be NULL, which is the same as the empty string.
- */
-static void action_m4_define (const char *defname, const char * value)
-{
-	char    buf[MAXLINE];
-
-    flexfatal ("DO NOT USE THIS FUNCTION!");
-
-	if ((int) strlen (defname) > MAXLINE / 2) {
-		format_pinpoint_message (_
-					 ("name \"%s\" ridiculously long"),
-					 defname);
-		return;
-	}
-
-	snprintf (buf, sizeof(buf), "m4_define([[%s]],[[%s]])m4_dnl\n", defname, value?value:"");
-	add_action (buf);
-}
-#endif
-
 /* Append "new_text" to the running buffer. */
 void add_action (const char *new_text)
 {
@@ -167,7 +143,7 @@ void add_action (const char *new_text)
 void   *allocate_array (int size, size_t element_size)
 {
 	void *mem;
-	size_t  num_bytes = element_size * size;
+	size_t  num_bytes = element_size * (size_t) size;
 
 	mem = malloc(num_bytes);
 	if (!mem)
@@ -326,9 +302,9 @@ void flexfatal (const char *msg)
 }
 
 
-/* htoi - convert a hexadecimal digit string to an integer value */
+/* htoui - convert a hexadecimal digit string to an unsigned integer value */
 
-int htoi (unsigned char str[])
+unsigned int htoui (unsigned char str[])
 {
 	unsigned int result;
 
@@ -386,8 +362,8 @@ void line_directive_out (FILE *output_file, int do_infile)
 	s3 = &filename[sizeof (filename) - 2];
 
 	while (s2 < s3 && *s1) {
-		if (*s1 == '\\')
-			/* Escape the '\' */
+		if (*s1 == '\\' || *s1 == '"')
+			/* Escape the '\' or '"' */
 			*s2++ = '\\';
 
 		*s2++ = *s1++;
@@ -536,7 +512,8 @@ unsigned char myesc (unsigned char array[])
 		{		/* \<octal> */
 			int     sptr = 1;
 
-			while (isascii (array[sptr]) &&
+			while (sptr <= 3 &&
+                               isascii (array[sptr]) &&
 			       isdigit (array[sptr]))
 				/* Don't increment inside loop control
 				 * because if isdigit() is a macro it might
@@ -547,7 +524,7 @@ unsigned char myesc (unsigned char array[])
 			c = array[sptr];
 			array[sptr] = '\0';
 
-			esc_char = otoi (array + 1);
+			esc_char = (unsigned char) otoui (array + 1);
 
 			array[sptr] = c;
 
@@ -569,7 +546,7 @@ unsigned char myesc (unsigned char array[])
 			c = array[sptr];
 			array[sptr] = '\0';
 
-			esc_char = htoi (array + 2);
+			esc_char = (unsigned char) htoui (array + 2);
 
 			array[sptr] = c;
 
@@ -582,9 +559,9 @@ unsigned char myesc (unsigned char array[])
 }
 
 
-/* otoi - convert an octal digit string to an integer value */
+/* otoui - convert an octal digit string to an unsigned integer value */
 
-int otoi (unsigned char str[])
+unsigned int otoui (unsigned char str[])
 {
 	unsigned int result;
 
@@ -692,7 +669,7 @@ char   *readable_form (int c)
 		return "' '";
 
 	else {
-		rform[0] = c;
+		rform[0] = (char) c;
 		rform[1] = '\0';
 
 		return rform;
@@ -705,7 +682,7 @@ char   *readable_form (int c)
 void   *reallocate_array (void *array, int size, size_t element_size)
 {
 	void *new_array;
-	size_t  num_bytes = element_size * size;
+	size_t  num_bytes = element_size * (size_t) size;
 
 	new_array = realloc(array, num_bytes);
 	if (!new_array)
